### Name: gbs
### Title: The generalized Birnbaum-Saunders distribution (GBSD)
### Aliases: dgbs pgbs qgbs rgbs
### Keywords: distribution

### ** Examples

## Computes the pdf of the GBSD with g = "normal" for a vector x with alpha = 1.0, 
## beta = 1.0
x  <- seq(0.01, 4, by = 0.01)
fx <- dgbs(x, alpha = 1.0, beta = 1.0, nu = 1.0, kernel = "normal")
print(fx)

## At the end there is a graph of this pdf
plot(x, fx, main = "pdf of the GBSD (classical case)", ylab = "f(x)")

## Computes the cdf of the GBSD with g = "normal" for a vector x with alpha = 1.0, 
## beta = 1.0
Fx <- pgbs(x, alpha = 1.0, beta = 1.0, nu = 1.0, kernel = "normal")
print(Fx)

## At the end there is a graph of this cdf
plot(x, Fx, main = "cdf of the GBSD (classical case)", ylab = "F(x)")

## Compute the 50 percentile (median) for a vector of probabilities x
## of the gbs with alpha = 1.0, beta = 1.0 and kernel = "normal"
q <- qgbs(0.5, alpha = 1.0, beta = 1.0, nu = 1.0, kernel = "normal")
q

## Generates a sample x from the GBSD with normal kernel. 
## At the end we have the histogram of x
x <- rgbs(1000, alpha = 1.0, beta = 1.0, nu = 1.0, kernel = "normal")
hist(x, main = "Histogram of a sample from GBSD")



